@@ -55,35 +55,35 @@ test_gcc_9() {
 test_arm64_gcc() {
     get_build_args arm64_gcc
     assertArg 'BASE=$(REGISTRY)$(PROJECT)/gcc' 'HOSTARCH=aarch64'\
-        'PACKAGES="gcc g++ gcc-aarch64-linux-gnu g++-aarch64-linux-gnu gcc-arm-linux-gnueabihf g++-arm-linux-gnueabihf"'
+        'PACKAGES="gcc g++ gcc-arm-linux-gnueabihf g++-arm-linux-gnueabihf gcc-aarch64-linux-gnu g++-aarch64-linux-gnu"'
 }
 
 test_arm64_gcc_8() {
     get_build_args arm64_gcc-8
     assertArg 'BASE=$(REGISTRY)$(PROJECT)/gcc' 'HOSTARCH=aarch64'\
-        'PACKAGES="gcc-8 g++-8 gcc-8-aarch64-linux-gnu g++-8-aarch64-linux-gnu gcc-8-arm-linux-gnueabihf g++-8-arm-linux-gnueabihf"'
+        'PACKAGES="gcc-8 g++-8 gcc-8-arm-linux-gnueabihf g++-8-arm-linux-gnueabihf gcc-8-aarch64-linux-gnu g++-8-aarch64-linux-gnu"'
 }
 
 test_x86_64_gcc() {
     get_build_args x86_64_gcc
     assertArg 'BASE=$(REGISTRY)$(PROJECT)/gcc' 'HOSTARCH=x86_64'\
-        'PACKAGES="gcc g++ gcc-x86-64-linux-gnu g++-x86-64-linux-gnu"'
+        'PACKAGES="gcc g++"'
 }
 
 test_clang() {
     get_build_args clang
-    assertArg 'BASE=$(REGISTRY)$(PROJECT)/base' 'PACKAGES="clang llvm lld"'
+    assertArg 'BASE=$(REGISTRY)$(PROJECT)/base' 'PACKAGES="clang clang-tidy llvm lld"'
 }
 
 test_arm64_clang() {
     get_build_args arm64_clang
     assertArg 'BASE=$(REGISTRY)$(PROJECT)/clang' 'HOSTARCH=aarch64' \
-        'PACKAGES="clang llvm lld binutils-aarch64-linux-gnu binutils-arm-linux-gnueabihf"'
+        'PACKAGES="clang clang-tidy llvm lld binutils-arm-linux-gnueabihf binutils-aarch64-linux-gnu"'
 }
 
 test_clang_11() {
     get_build_args clang-11
-    assertArg 'BASE=$(REGISTRY)$(PROJECT)/base' 'PACKAGES="clang-11 llvm-11 lld-11"'
+    assertArg 'BASE=$(REGISTRY)$(PROJECT)/base' 'PACKAGES="clang-11 clang-tidy-11 llvm-11 lld-11"'
 }
 
 test_gcc_all_includes_only_gcc_images_not_gcc_N() {
@@ -106,4 +106,9 @@ test_clang_all_includes_only_glang_images_not_clang_N() {
     fi
 }
 
+if [ "$(uname -m)" != "x86_64" ]; then
+    echo "I: skipping tests, as they only apply on x86_64"
+    exit
+fi
+
 . /usr/share/shunit2/shunit2
